==> icefaces-ace-4.0.0.jar: META-INF/resources/icefaces.ace/list/list.c.js <==
window.ice.ace||(window.ice.ace={});ice.ace.Lists||(ice.ace.Lists={});
ice.ace.List=function(a,b){var d=this;this.id=a;this.jqId=ice.ace.escapeClientId(this.id);this.cfg=b;this.sep=String.fromCharCode(this.cfg.separator);this.element=ice.ace.jq(this.jqId);this.behaviors=b.behaviors;if(ice.ace.Lists[a]){var c=ice.ace.Lists[a];c.disableClickHandling&&(this.disableClickHandling=!0);c.disableDoubleClickHandling&&(this.disableDoubleClickHandling=!0);setTimeout(function(){d.disableClickHandling=!1;d.disableDoubleClickHandling=!1},500)}ice.ace.Lists[a]=d;this.appStartHandler=
this.cfg.start;b.start=function(a,b){var c=ice.ace.jq(a.currentTarget).find(".if-list-plhld"),h=ice.ace.jq(a.originalEvent.target).closest("li"),k=h.width(),h=h.height();c.width(k+"px").height(h+"px");d.dragFromHandler.call(d,a,b);return d.appStartHandler?d.appStartHandler(a,b):!0};this.appStopHandler=this.cfg.stop;b.stop=function(a,b){d.dragToHandler.call(d,a,b);return d.appStopHandler?d.appStopHandler.call(d,a,b):!0};this.appRecieveHandler=this.cfg.receive;b.receive=function(a,b){d.itemReceiveHandler.call(d,
a,b);return d.appRecieveHandler?d.appRecieveHandler.call(d,a,b):!0};b.selection&&this.setupSelection();b.dblclk_migrate&&this.setupClickMigration();b.controls&&this.setupControls();b.dragging&&this.element.find("> ul").sortable(b)};
ice.ace.List.prototype.itemReceiveHandler=function(a,b){var d=b.item,c=d.attr("id"),c=parseInt(c.substr(c.lastIndexOf(this.sep)+1)),e=b.sender.closest(".if-list").attr("id"),f=ice.ace.Lists[e],c=f.getUnshiftedIndex(f.element.find("> ul").children().length,f.read("reorderings"),c);this.immigrantMessage=[];this.immigrantMessage.push(e);this.immigrantMessage.push([[c,d.index()]]);f.cfg.selection&&(this.deselectConnectedLists(),this.deselectAll(d),f.addSelectedItem(d,c));this.sendMigrateRequest()};
ice.ace.List.prototype.sendMigrateRequest=function(a){var b=this,d=b.immigrantMessage[0],c=ice.ace.Lists[d],e={source:b.id,execute:b.id+" "+d,render:b.id+" "+d},f={};f[d+"_emigration"]=b.id;f[b.id+"_immigration"]=JSON.stringify(b.immigrantMessage);e.params=f;e.onsuccess=function(d){b.element=ice.ace.jq(ice.ace.escapeClientId(b.element.attr("id")));b.cfg.dragging&&b.element.find("> ul").sortable(b.cfg);c.element=ice.ace.jq(ice.ace.escapeClientId(c.element.attr("id")));c.cfg.dragging&&c.element.find("> ul").sortable(c.cfg);
ice.ace.jq.isFunction(a)&&a();return!0};this.behaviors&&this.behaviors.migrate?ice.ace.ab(ice.ace.extendAjaxArgs(this.behaviors.migrate,e)):ice.ace.AjaxRequest(e);this.clearState();c.clearState();c.element.find("> ul > li.ui-state-active").remove()};ice.ace.List.prototype.dragFromHandler=function(a,b){this.startIndex=b.item.index()};
ice.ace.List.prototype.dragToHandler=function(a,b){var d=b.item,c=this;ice.ace.jq.browser.chrome||ice.ace.jq.browser.safari||setTimeout(function(){ice.ace.util.isMouseOver(d,a)||c.itemLeave({currentTarget:d})},100);if(0<b.item.parents(this.jqId).length){var e=this.read("reorderings"),f=e.length,g=b.item.index(),h=g>this.startIndex,k=b.item,m=h?k.prev():k.next(),l=d.attr("id"),l=parseInt(l.substr(l.lastIndexOf(this.sep)+1)),l=this.getUnshiftedIndex(this.element.find("> ul").children().length,this.read("reorderings"),
l);if(g!=this.startIndex){this.cfg.selection&&(this.deselectAll(),this.deselectConnectedLists(),this.addSelectedItem(d,l));do g=[],g.push(m.index()),g.push(k.index()),e.splice(f,0,g),this.swapIdPrefix(m,k),k=m,m=h?k.prev():k.next();while(k.index()!=this.startIndex)}this.write("reorderings",e);this.behaviors&&this.behaviors.move&&(c=this,this.behaviors.move.oncomplete=function(){c.clearState()},ice.ace.ab(this.behaviors.move))}};
ice.ace.List.prototype.setupControls=function(){var a=this;this.element.off("mouseenter"," > div.if-list-ctrls .if-list-ctrl").on("mouseenter"," > div.if-list-ctrls .if-list-ctrl",function(a){ice.ace.jq(a.currentTarget).addClass("ui-state-hover")}).off("mouseleave"," > div.if-list-ctrls .if-list-ctrl").on("mouseleave"," > div.if-list-ctrls .if-list-ctrl",function(a){ice.ace.jq(a.currentTarget).removeClass("ui-state-hover")}).off("click"," > div.if-list-ctrls .if-list-ctrl").on("click"," > div.if-list-ctrls .if-list-ctrl",
function(b){a.controlClickHandler.call(a,b)})};ice.ace.List.prototype.controlClickHandler=function(a){a=ice.ace.jq(a.currentTarget);var b;ice.ace.jq.browser.msie&&9!=ice.ace.jq.browser.version||a.toggleClass("ui-state-active",50).toggleClass("ui-state-active",50);a.hasClass("if-list-ctrl-top")?b="top":a.hasClass("if-list-ctrl-up")?b="up":a.hasClass("if-list-ctrl-dwn")?b="dwn":a.hasClass("if-list-ctrl-btm")&&(b="btm");this.moveItems(b)};
ice.ace.List.prototype.setupSelection=function(){var a=this;ice.ace.jq(this.element).off("mouseenter mouseleave click"," > ul > li:not(.disabled)").on("mouseenter"," > ul > li:not(.disabled)",this.itemEnter).on("mouseleave"," > ul > li:not(.disabled)",this.itemLeave).on("click"," > ul > li:not(.disabled)",function(b){a.itemClickHandler.call(a,b)})};
ice.ace.List.prototype.setupClickMigration=function(){var a=this;ice.ace.jq(this.element).off("dblclick"," > ul > li").on("dblclick"," > ul > li",function(b){a.itemDoubleClickHandler.call(a,b)})};ice.ace.List.prototype.itemEnter=function(a){ice.ace.jq(a.currentTarget).addClass("ui-state-hover")};ice.ace.List.prototype.itemLeave=function(a){ice.ace.jq(a.currentTarget).removeClass("ui-state-hover")};
ice.ace.List.prototype.itemDoubleClickHandler=function(a){if(!this.disableDoubleClickHandling){var b=ice.ace.jq(a.currentTarget),d=this,c=b.attr("id"),e=this,c=parseInt(c.substr(c.lastIndexOf(this.sep)+1));a=this.getSiblingList(a.shiftKey);clearTimeout(this.pendingClickHandling);this.pendingClickHandling=void 0;c=this.getUnshiftedIndex(this.element.find("> ul").children().length,this.read("reorderings"),c);void 0==a?(d.disableDoubleClickHandling=!1,d.disableClickHandling=!1):(a.immigrantMessage=[],
a.immigrantMessage.push(this.id),a.immigrantMessage.push([[c,a.element.find("> ul").children().length]]),this.cfg.selection&&(a.deselectConnectedLists(),a.deselectAll(),this.addSelectedItem(b,c)),setTimeout(function(){d.disableDoubleClickHandling=!1;d.disableClickHandling=!1},500),a.sendMigrateRequest(function(){e.doubleClickAttempted=!1}))}};
ice.ace.List.prototype.getSiblingList=function(a){for(var b in ice.ace.ListControls)if(ice.ace.ListControls.hasOwnProperty(b)){var d=ice.ace.jq(ice.ace.ListControls[b].selector),c=this.element.parent().parent(),c=a||c.hasClass("if-list-dl-2"),e=d.index(this.element);if(!(0>e)){e=c?d.index(this.element)-1:d.index(this.element)+1;if(!c&&e>=d.length||c&&0>e)break;if(0<=e)return ice.ace.Lists[ice.ace.jq(d[e]).attr("id")]}}};ice.ace.List.prototype.pendingClickHandling;ice.ace.List.prototype.lastClickedIndex;
ice.ace.List.prototype.disableClickHandling=!1;ice.ace.List.prototype.disableDoubleClickHandling=!1;
ice.ace.List.prototype.itemClickHandler=function(a){if(void 0==this.pendingClickHandling&&!this.disableClickHandling){var b=ice.ace.jq(a.currentTarget),d=this,c=this.cfg.dblclk_migrate?250:0;this.disableClickHandling=!0;this.pendingClickHandling=setTimeout(function(){var c=b.index();d.deselectConnectedLists();if(a.shiftKey&&"single"!=d.cfg.selection){d.clearSelection();var f,g;g=d.lastClickedIndex?d.lastClickedIndex:-1;g<c?(f=g+1,g=c+1):f=c;b.parent().children().slice(f,g).filter(":not(.ui-state-active)").each(function(){d.addSelectedItem(ice.ace.jq(this),
null,!0)});d.behaviors&&d.behaviors.select&&(d.behaviors.select.oncomplete=function(){d.clearState()},ice.ace.ab(d.behaviors.select))}else{var h=b.hasClass("ui-state-active");f=function(){h?d.removeSelectedItem(b):d.addSelectedItem(b)};!a.metaKey&&!a.ctrlKey||"single"==d.cfg.selection?d.deselectAll(null,f):f()}d.lastClickedIndex=c;d.pendingClickHandling=void 0;d.disableClickHandling=!1},c)}};
ice.ace.List.prototype.getUnshiftedIndex=function(a,b,d){for(var c=[],e=0;0<=a-e;e++)c.push(e);for(e=0;e<b.length;e++)a=b[e][0],to=b[e][1],t=c[to],c[to]=c[a],c[a]=t;return c[d]};
ice.ace.List.prototype.addSelectedItem=function(a,b,d){if(!a.hasClass("ui-state-active")){var c=this.read("selections"),e=this.read("deselections"),f=this.read("reorderings"),g=a.attr("id"),h;b?h=b:(h=g.substr(g.lastIndexOf(this.sep)+1),h=this.getUnshiftedIndex(a.siblings().length,f,parseInt(h)));a.addClass("ui-state-active");e=ice.ace.jq.grep(e,function(a){return a!=h});c.push(h);this.write("selections",c);this.write("deselections",e);if(this.behaviors&&!d&&this.behaviors.select){var k=this;this.behaviors.select.oncomplete=
function(){k.clearState()};ice.ace.ab(this.behaviors.select)}}};ice.ace.List.prototype.deselectConnectedLists=function(){for(var a in ice.ace.ListControls)if(ice.ace.ListControls.hasOwnProperty(a)){var b=ice.ace.jq(ice.ace.ListControls[a].selector);b.is(this.element)&&b.not(this.element).each(function(a,b){ice.ace.Lists[ice.ace.jq(b).attr("id")].deselectAll()})}};
ice.ace.List.prototype.removeSelectedItem=function(a){if(a.hasClass("ui-state-active")){var b=this.read("selections"),d=this.read("deselections"),c=this.read("reorderings"),e=a.attr("id"),f=e.substr(e.lastIndexOf(this.sep)+1),c=this.getUnshiftedIndex(a.siblings().length,c,parseInt(f));a.removeClass("ui-state-active");b=ice.ace.jq.grep(b,function(a){return a!=f});d.push(c);this.write("selections",b);this.write("deselections",d);if(this.behaviors&&this.behaviors.deselect){var g=this;this.behaviors.deselect.oncomplete=
function(){g.clearState()};ice.ace.ab(this.behaviors.deselect)}}};
ice.ace.List.prototype.deselectAll=function(a,b){var d=this,c=this.read("reorderings"),e=this.read("selections"),f=this.read("deselections");this.element.find("> ul.if-list-body > li.if-list-item.ui-state-active").each(function(b,g){if(void 0==a||!a.is(g)){var m=ice.ace.jq(g),l=m.attr("id"),n=parseInt(l.substr(l.lastIndexOf(d.sep)+1));m.removeClass("ui-state-active");void 0!=n&&(n=d.getUnshiftedIndex(m.parent().children().length,c,n));void 0!=n&&(f.push(n),e=ice.ace.jq.grep(e,function(a){return a!=
n}))}});this.write("selections",e);this.write("deselections",f);if(this.behaviors&&this.behaviors.deselect&&!isNaN(f.length)&&0<f.length){var g=this;this.behaviors.deselect.oncomplete=function(){g.clearState();b&&b()};ice.ace.ab(this.behaviors.deselect)}else b&&b()};ice.ace.List.prototype.clearState=function(){this.write("reorderings",[]);this.write("selections",[]);this.write("deselections",[])};
ice.ace.List.prototype.moveItems=function(a){var b=this.element.find(".ui-state-active");if(0<b.length){var d=this.read("reorderings");if("top"==a)for(a=b.length-1;0<=a;a--){var c=ice.ace.jq(b[a]),e=c.prev();if(0<e.length){do{var f=[];f.push(c.index());e.before(c);f.push(c.index());d.push(f);this.swapIdPrefix(c,e);e=c.prev()}while(0<e.length)}}else if("up"==a)for(a=0;a<b.length;a++)c=ice.ace.jq(b[a]),f=[],f.push(c.index()),e=c.prev(":first"),e.before(c),f.push(c.index()),d.push(f),this.swapIdPrefix(c,
e);else if("dwn"==a||"down"==a)for(a=b.length-1;0<=a;a--)c=ice.ace.jq(b[a]),f=[],f.push(c.index()),e=c.next(":first"),e.after(c),f.push(c.index()),d.push(f),this.swapIdPrefix(c,e);else if("btm"==a||"bottom"==a)for(a=0;a<b.length;a++)if(c=ice.ace.jq(b[a]),e=c.next(),0<e.length){do f=[],f.push(c.index()),e.after(c),f.push(c.index()),d.push(f),this.swapIdPrefix(c,e),e=c.next();while(0<e.length)}this.write("reorderings",d);if(this.behaviors&&this.behaviors.move){var g=this;this.behaviors.move.oncomplete=
function(){g.clearState()};ice.ace.ab(this.behaviors.move)}}};ice.ace.List.prototype.swapIdPrefix=function(a,b){if(0!=a.length&&0!=b.length){var d=a.attr("id"),c=b.attr("id"),e=a.find('*[id^="'+d+'"]'),f=b.find('*[id^="'+c+'"]');a.attr("id",c);b.attr("id",d);for(var g=0;g<e.length;g++){var h=ice.ace.jq(e[g]);h.attr("id",h.attr("id").replace(d,c))}for(g=0;g<f.length;g++)h=ice.ace.jq(f[g]),h.attr("id",h.attr("id").replace(c,d))}};
ice.ace.List.prototype.read=function(a){a=ice.ace.jq(ice.ace.escapeClientId(this.element.attr("id"))).children('input[name="'+this.jqId.substr(1)+"_"+a+'"]').val();return""!=a&&void 0!=a?JSON.parse(a):[]};ice.ace.List.prototype.write=function(a,b){ice.ace.jq(ice.ace.escapeClientId(this.element.attr("id"))).children('input[name="'+this.jqId.substr(1)+"_"+a+'"]').attr("value",JSON.stringify(b))};
ice.ace.List.prototype.clearSelection=function(){window.getSelection?window.getSelection().empty?window.getSelection().empty():window.getSelection().removeAllRanges&&window.getSelection().removeAllRanges():document.selection&&document.selection.empty()};

==> icefaces-ace-4.2.0.jar: META-INF/resources/icefaces.ace/list/list.c.js <==
window.ice.ace||(window.ice.ace={});ice.ace.Lists||(ice.ace.Lists={});
ice.ace.List=function(a,b){var d=this;this.id=a;this.jqId=ice.ace.escapeClientId(this.id);this.cfg=b;this.sep=String.fromCharCode(this.cfg.separator);this.element=ice.ace.jq(this.jqId);this.behaviors=b.behaviors;if(ice.ace.Lists[a]){var c=ice.ace.Lists[a];c.disableClickHandling&&(this.disableClickHandling=!0);c.disableDoubleClickHandling&&(this.disableDoubleClickHandling=!0);setTimeout(function(){d.disableClickHandling=!1;d.disableDoubleClickHandling=!1},500)}ice.ace.Lists[a]=d;this.appStartHandler=
this.cfg.start;b.start=function(a,b){var c=ice.ace.jq(a.currentTarget).find(".if-list-plhld"),h=ice.ace.jq(a.originalEvent.target).closest("li"),k=h.width(),h=h.height();c.width(k+"px").height(h+"px");d.dragFromHandler.call(d,a,b);return d.appStartHandler?d.appStartHandler(a,b):!0};this.appStopHandler=this.cfg.stop;b.stop=function(a,b){d.dragToHandler.call(d,a,b);return d.appStopHandler?d.appStopHandler.call(d,a,b):!0};this.appRecieveHandler=this.cfg.receive;b.receive=function(a,b){d.itemReceiveHandler.call(d,
a,b);return d.appRecieveHandler?d.appRecieveHandler.call(d,a,b):!0};b.selection&&this.setupSelection();b.dblclk_migrate&&this.setupClickMigration();b.controls&&this.setupControls();b.dragging?(c={placeholder:b.placeholder,start:b.start,stop:b.stop,receive:b.receive},b.connectWith&&(c.connectWith=b.connectWith),this.element.find("> ul").sortable(c),this.element.find("> ul").sortable("option","disabled",!1),this.element.find("> ul").disableSelection()):this.element.find("> ul").sortable("option","disabled",
!0)};ice.ace.List.prototype.itemReceiveHandler=function(a,b){var d=b.item,c=d.attr("id"),c=parseInt(c.substr(c.lastIndexOf(this.sep)+1)),e=b.sender.closest(".if-list").attr("id"),f=ice.ace.Lists[e],c=f.getUnshiftedIndex(f.element.find("> ul").children().length,f.read("reorderings"),c);this.immigrantMessage=[];this.immigrantMessage.push(e);this.immigrantMessage.push([[c,d.index()]]);f.cfg.selection&&(this.deselectConnectedLists(),this.deselectAll(d),f.addSelectedItem(d,c));this.sendMigrateRequest()};
ice.ace.List.prototype.sendMigrateRequest=function(a){var b=this,d=b.immigrantMessage[0],c=ice.ace.Lists[d],e={source:b.id,execute:b.id+" "+d,render:b.id+" "+d},f={};f[d+"_emigration"]=b.id;f[b.id+"_immigration"]=JSON.stringify(b.immigrantMessage);e.params=f;e.onsuccess=function(d){b.element=ice.ace.jq(ice.ace.escapeClientId(b.element.attr("id")));b.cfg.dragging&&b.element.find("> ul").sortable(b.cfg);c.element=ice.ace.jq(ice.ace.escapeClientId(c.element.attr("id")));c.cfg.dragging&&c.element.find("> ul").sortable(c.cfg);
ice.ace.jq.isFunction(a)&&a();return!0};this.behaviors&&this.behaviors.migrate?ice.ace.ab(ice.ace.extendAjaxArgs(this.behaviors.migrate,e)):ice.ace.AjaxRequest(e);this.clearState();c.clearState();c.element.find("> ul > li.ui-state-active").remove()};ice.ace.List.prototype.dragFromHandler=function(a,b){this.startIndex=b.item.index()};
ice.ace.List.prototype.dragToHandler=function(a,b){var d=b.item,c=this;ice.ace.jq.browser.chrome||ice.ace.jq.browser.safari||setTimeout(function(){ice.ace.util.isMouseOver(d,a)||c.itemLeave({currentTarget:d})},100);if(0<b.item.parents(this.jqId).length){var e=this.read("reorderings"),f=e.length,g=b.item.index(),h=g>this.startIndex,k=b.item,m=h?k.prev():k.next(),l=d.attr("id"),l=parseInt(l.substr(l.lastIndexOf(this.sep)+1)),l=this.getUnshiftedIndex(this.element.find("> ul").children().length,this.read("reorderings"),
l);if(g!=this.startIndex){this.cfg.selection&&(this.deselectAll(),this.deselectConnectedLists(),this.addSelectedItem(d,l));do g=[],g.push(m.index()),g.push(k.index()),e.splice(f,0,g),this.swapIdPrefix(m,k),k=m,m=h?k.prev():k.next();while(k.index()!=this.startIndex)}this.write("reorderings",e);this.behaviors&&this.behaviors.move&&(c=this,this.behaviors.move.oncomplete=function(){c.clearState()},ice.ace.ab(this.behaviors.move))}};
ice.ace.List.prototype.setupControls=function(){var a=this;this.element.off("mouseenter"," > div.if-list-ctrls .if-list-ctrl").on("mouseenter"," > div.if-list-ctrls .if-list-ctrl",function(a){ice.ace.jq(a.currentTarget).addClass("ui-state-hover")}).off("mouseleave"," > div.if-list-ctrls .if-list-ctrl").on("mouseleave"," > div.if-list-ctrls .if-list-ctrl",function(a){ice.ace.jq(a.currentTarget).removeClass("ui-state-hover")}).off("click"," > div.if-list-ctrls .if-list-ctrl").on("click"," > div.if-list-ctrls .if-list-ctrl",
function(b){a.controlClickHandler.call(a,b)})};ice.ace.List.prototype.controlClickHandler=function(a){a=ice.ace.jq(a.currentTarget);var b;ice.ace.jq.browser.msie&&9!=ice.ace.jq.browser.version||a.toggleClass("ui-state-active",50).toggleClass("ui-state-active",50);a.hasClass("if-list-ctrl-top")?b="top":a.hasClass("if-list-ctrl-up")?b="up":a.hasClass("if-list-ctrl-dwn")?b="dwn":a.hasClass("if-list-ctrl-btm")&&(b="btm");this.moveItems(b)};
ice.ace.List.prototype.setupSelection=function(){var a=this;ice.ace.jq(this.element).off("mouseenter mouseleave click"," > ul > li:not(.disabled)").on("mouseenter"," > ul > li:not(.disabled)",this.itemEnter).on("mouseleave"," > ul > li:not(.disabled)",this.itemLeave).on("click"," > ul > li:not(.disabled)",function(b){a.itemClickHandler.call(a,b)})};
ice.ace.List.prototype.setupClickMigration=function(){var a=this;ice.ace.jq(this.element).off("dblclick"," > ul > li").on("dblclick"," > ul > li",function(b){a.itemDoubleClickHandler.call(a,b)})};ice.ace.List.prototype.itemEnter=function(a){ice.ace.jq(a.currentTarget).addClass("ui-state-hover")};ice.ace.List.prototype.itemLeave=function(a){ice.ace.jq(a.currentTarget).removeClass("ui-state-hover")};
ice.ace.List.prototype.itemDoubleClickHandler=function(a){if(!this.disableDoubleClickHandling){var b=ice.ace.jq(a.currentTarget),d=this,c=b.attr("id"),e=this,c=parseInt(c.substr(c.lastIndexOf(this.sep)+1));a=this.getSiblingList(a.shiftKey);clearTimeout(this.pendingClickHandling);this.pendingClickHandling=void 0;c=this.getUnshiftedIndex(this.element.find("> ul").children().length,this.read("reorderings"),c);void 0==a?(d.disableDoubleClickHandling=!1,d.disableClickHandling=!1):(a.immigrantMessage=[],
a.immigrantMessage.push(this.id),a.immigrantMessage.push([[c,a.element.find("> ul").children().length]]),this.cfg.selection&&(a.deselectConnectedLists(),a.deselectAll(),this.addSelectedItem(b,c)),setTimeout(function(){d.disableDoubleClickHandling=!1;d.disableClickHandling=!1},500),a.sendMigrateRequest(function(){e.doubleClickAttempted=!1}))}};
ice.ace.List.prototype.getSiblingList=function(a){for(var b in ice.ace.ListControls)if(ice.ace.ListControls.hasOwnProperty(b)){var d=ice.ace.jq(ice.ace.ListControls[b].selector),c=this.element.parent().parent(),c=a||c.hasClass("if-list-dl-2"),e=d.index(this.element);if(!(0>e)){e=c?d.index(this.element)-1:d.index(this.element)+1;if(!c&&e>=d.length||c&&0>e)break;if(0<=e)return ice.ace.Lists[ice.ace.jq(d[e]).attr("id")]}}};ice.ace.List.prototype.pendingClickHandling;ice.ace.List.prototype.lastClickedIndex;
ice.ace.List.prototype.disableClickHandling=!1;ice.ace.List.prototype.disableDoubleClickHandling=!1;
ice.ace.List.prototype.itemClickHandler=function(a){if(void 0==this.pendingClickHandling&&!this.disableClickHandling){var b=ice.ace.jq(a.currentTarget),d=this,c=this.cfg.dblclk_migrate?250:0;this.disableClickHandling=!0;this.pendingClickHandling=setTimeout(function(){var c=b.index();d.deselectConnectedLists();if(a.shiftKey&&"single"!=d.cfg.selection){d.clearSelection();var f,g;g=d.lastClickedIndex?d.lastClickedIndex:-1;g<c?(f=g+1,g=c+1):f=c;b.parent().children().slice(f,g).filter(":not(.ui-state-active)").each(function(){d.addSelectedItem(ice.ace.jq(this),
null,!0)});d.behaviors&&d.behaviors.select&&(d.behaviors.select.oncomplete=function(){d.clearState()},ice.ace.ab(d.behaviors.select))}else{var h=b.hasClass("ui-state-active");f=function(){h?d.removeSelectedItem(b):d.addSelectedItem(b)};!a.metaKey&&!a.ctrlKey||"single"==d.cfg.selection?d.deselectAll(null,f):f()}d.lastClickedIndex=c;d.pendingClickHandling=void 0;d.disableClickHandling=!1},c)}};
ice.ace.List.prototype.getUnshiftedIndex=function(a,b,d){if(0==b.length)return d;for(var c=[],e=0;0<=a-e;e++)c.push(e);for(e=0;e<b.length;e++)a=b[e][0],to=b[e][1],t=c[to],c[to]=c[a],c[a]=t;return c[d]};
ice.ace.List.prototype.addSelectedItem=function(a,b,d){if(!a.hasClass("ui-state-active")){var c=this.read("selections"),e=this.read("deselections"),f=this.read("reorderings"),g=a.attr("id"),h;b?h=b:(h=g.substr(g.lastIndexOf(this.sep)+1),h=this.getUnshiftedIndex(a.siblings().length,f,parseInt(h)));a.addClass("ui-state-active");e=ice.ace.jq.grep(e,function(a){return a!=h});c.push(h);this.write("selections",c);this.write("deselections",e);if(this.behaviors&&!d&&this.behaviors.select){var k=this;this.behaviors.select.oncomplete=
function(){k.clearState()};ice.ace.ab(this.behaviors.select)}}};ice.ace.List.prototype.deselectConnectedLists=function(){for(var a in ice.ace.ListControls)if(ice.ace.ListControls.hasOwnProperty(a)){var b=ice.ace.jq(ice.ace.ListControls[a].selector);b.is(this.element)&&b.not(this.element).each(function(a,b){ice.ace.Lists[ice.ace.jq(b).attr("id")].deselectAll()})}};
ice.ace.List.prototype.removeSelectedItem=function(a){if(a.hasClass("ui-state-active")){var b=this.read("selections"),d=this.read("deselections"),c=this.read("reorderings"),e=a.attr("id"),f=e.substr(e.lastIndexOf(this.sep)+1),c=this.getUnshiftedIndex(a.siblings().length,c,parseInt(f));a.removeClass("ui-state-active");b=ice.ace.jq.grep(b,function(a){return a!=f});d.push(c);this.write("selections",b);this.write("deselections",d);if(this.behaviors&&this.behaviors.deselect){var g=this;this.behaviors.deselect.oncomplete=
function(){g.clearState()};ice.ace.ab(this.behaviors.deselect)}}};
ice.ace.List.prototype.deselectAll=function(a,b){var d=this,c=this.read("reorderings"),e=this.read("selections"),f=this.read("deselections");this.element.find("> ul.if-list-body > li.if-list-item.ui-state-active").each(function(b,g){if(void 0==a||!a.is(g)){var m=ice.ace.jq(g),l=m.attr("id"),n=parseInt(l.substr(l.lastIndexOf(d.sep)+1));m.removeClass("ui-state-active");void 0!=n&&(n=d.getUnshiftedIndex(m.parent().children().length,c,n));void 0!=n&&(f.push(n),e=ice.ace.jq.grep(e,function(a){return a!=
n}))}});this.write("selections",e);this.write("deselections",f);if(this.behaviors&&this.behaviors.deselect&&!isNaN(f.length)&&0<f.length){var g=this;this.behaviors.deselect.oncomplete=function(){g.clearState();b&&b()};ice.ace.ab(this.behaviors.deselect)}else b&&b()};ice.ace.List.prototype.clearState=function(){this.write("reorderings",[]);this.write("selections",[]);this.write("deselections",[])};
ice.ace.List.prototype.moveItems=function(a){var b=this.element.find(".ui-state-active");if(0<b.length){var d=this.read("reorderings");if("top"==a)for(a=b.length-1;0<=a;a--){var c=ice.ace.jq(b[a]),e=c.prev();if(0<e.length){do{var f=[];f.push(c.index());e.before(c);f.push(c.index());d.push(f);this.swapIdPrefix(c,e);e=c.prev()}while(0<e.length)}}else if("up"==a)for(a=0;a<b.length;a++)c=ice.ace.jq(b[a]),f=[],f.push(c.index()),e=c.prev(":first"),e.before(c),f.push(c.index()),d.push(f),this.swapIdPrefix(c,
e);else if("dwn"==a||"down"==a)for(a=b.length-1;0<=a;a--)c=ice.ace.jq(b[a]),f=[],f.push(c.index()),e=c.next(":first"),e.after(c),f.push(c.index()),d.push(f),this.swapIdPrefix(c,e);else if("btm"==a||"bottom"==a)for(a=0;a<b.length;a++)if(c=ice.ace.jq(b[a]),e=c.next(),0<e.length){do f=[],f.push(c.index()),e.after(c),f.push(c.index()),d.push(f),this.swapIdPrefix(c,e),e=c.next();while(0<e.length)}this.write("reorderings",d);if(this.behaviors&&this.behaviors.move){var g=this;this.behaviors.move.oncomplete=
function(){g.clearState()};ice.ace.ab(this.behaviors.move)}}};ice.ace.List.prototype.swapIdPrefix=function(a,b){if(0!=a.length&&0!=b.length){var d=a.attr("id"),c=b.attr("id"),e=a.find('*[id^="'+d+'"]'),f=b.find('*[id^="'+c+'"]');a.attr("id",c);b.attr("id",d);for(var g=0;g<e.length;g++){var h=ice.ace.jq(e[g]);h.attr("id",h.attr("id").replace(d,c))}for(g=0;g<f.length;g++)h=ice.ace.jq(f[g]),h.attr("id",h.attr("id").replace(c,d))}};
ice.ace.List.prototype.read=function(a){a=ice.ace.jq(ice.ace.escapeClientId(this.element.attr("id"))).children('input[name="'+this.jqId.substr(1)+"_"+a+'"]').val();return""!=a&&void 0!=a?JSON.parse(a):[]};ice.ace.List.prototype.write=function(a,b){ice.ace.jq(ice.ace.escapeClientId(this.element.attr("id"))).children('input[name="'+this.jqId.substr(1)+"_"+a+'"]').attr("value",JSON.stringify(b))};
ice.ace.List.prototype.clearSelection=function(){window.getSelection?window.getSelection().empty?window.getSelection().empty():window.getSelection().removeAllRanges&&window.getSelection().removeAllRanges():document.selection&&document.selection.empty()};
